@@ -1,5 +1,7 @@
 import dataclasses
+import tempfile
 import typing
+import typing_extensions
 
 import logging
 
@@ -43,8 +45,8 @@ class Encoder:
     frozen=True,
 )
 class Connector:
-    type: str
     params: typing.Dict[str, typing.Any]
+    type: typing_extensions.Literal['redis', 'mongo', 'local'] = 'local'
 
 
 @dataclasses.dataclass(
@@ -67,7 +69,14 @@ class Starvation:
 )
 class WorkerConfig:
     name: str
-    connector: Connector
+    connector: Connector = dataclasses.field(
+        default_factory=lambda: Connector(
+            type='local',
+            params={
+                'file_path': f'{tempfile.gettempdir()}/sergeant_default_db.sqlite3',
+            },
+        ),
+    )
     max_tasks_per_run: int = 0
     max_retries: int = 0
     tasks_per_transaction: int = 1
