@@ -14,14 +14,14 @@ import typing
 class ReturnCode(
     enum.Enum,
 ):
-    WORKER_EXITED_NORMALLY: int = 0
-    WORKER_EXITED_ABNORMALLY: int = 1
-    WORKER_MODULE_NOT_FOUND: int = 2
-    WORKER_CLASS_NOT_FOUND: int = 3
-    WORKER_ASKED_TO_RESPAWN: int = 4
-    WORKER_ASKED_TO_STOP: int = 5
-    WORKER_EXECUTION_FAILURE: int = 6
-    WORKER_MODULE_NOT_IMPORTABLE: int = 7
+    WORKER_EXITED_NORMALLY = 0
+    WORKER_EXITED_ABNORMALLY = 1
+    WORKER_MODULE_NOT_FOUND = 2
+    WORKER_CLASS_NOT_FOUND = 3
+    WORKER_ASKED_TO_RESPAWN = 4
+    WORKER_ASKED_TO_STOP = 5
+    WORKER_EXECUTION_FAILURE = 6
+    WORKER_MODULE_NOT_IMPORTABLE = 7
 
 
 def work(
