@@ -16,17 +16,11 @@ from . import objects
 
 
 class Worker:
-    config = config.WorkerConfig(
-        name='test_worker',
-        connector=config.Connector(
-            type='redis',
-            params={},
-        ),
-    )
-
     def __init__(
         self,
     ) -> None:
+        self.config = self.generate_config()
+
         self.logger = logging.getLogger(
             name=self.config.name,
         )
@@ -41,21 +35,28 @@ class Worker:
         self.logger.addHandler(
             hdlr=logging.NullHandler(),
         )
+        self.executor_obj: typing.Optional[executor._executor.Executor] = None
 
-        self.stop_signal_received: bool = False
-        signal.signal(signal.SIGUSR1, self.stop_signal_handler)
+        signal.signal(signal.SIGTERM, self.stop_signal_handler)
+
+    def generate_config(
+        self,
+    ) -> config.WorkerConfig:
+        return config.WorkerConfig(
+            name='worker',
+        )
 
     def stop_signal_handler(
         self,
         signal_num: int,
         frame: typing.Optional[types.FrameType],
     ) -> None:
-        self.stop_signal_received = True
-
         self.logger.info(
             msg='stop signal has been received',
         )
-        signal.signal(signal.SIGUSR1, signal.SIG_DFL)
+        signal.signal(signal.SIGTERM, signal.SIG_DFL)
+
+        raise WorkerStop()
 
     def init_worker(
         self,
@@ -108,6 +109,8 @@ class Worker:
             connector_obj = connector.mongo.Connector(**self.config.connector.params)
         elif self.config.connector.type == 'redis':
             connector_obj = connector.redis.Connector(**self.config.connector.params)
+        elif self.config.connector.type == 'local':
+            connector_obj = connector.local.Connector(**self.config.connector.params)
         else:
             raise ValueError(f'connector type {self.config.connector.type} is not supported')
 
@@ -119,7 +122,6 @@ class Worker:
     def init_executor(
         self,
     ) -> None:
-        self.executor_obj: executor._executor.Executor
         if self.config.number_of_threads == 1:
             self.executor_obj = executor.serial.SerialExecutor(
                 worker_object=self,
@@ -130,6 +132,16 @@ class Worker:
                 number_of_threads=self.config.number_of_threads,
             )
 
+    def get_trace_id(
+        self,
+    ) -> typing.Optional[str]:
+        if self.executor_obj is not None:
+            current_task = self.executor_obj.get_current_task()
+            if current_task:
+                return current_task.trace_id
+
+        return None
+
     def purge_tasks(
         self,
         task_name: typing.Optional[str] = None,
@@ -154,9 +166,11 @@ class Worker:
         task_name: typing.Optional[str] = None,
         priority: str = 'NORMAL',
         consumable_from: int = 0,
+        trace_id: typing.Optional[str] = None,
     ) -> bool:
         task = objects.Task(
             kwargs=kwargs,
+            trace_id=trace_id if trace_id is not None else self.get_trace_id(),
         )
 
         return self.broker.push_task(
@@ -172,10 +186,13 @@ class Worker:
         task_name: typing.Optional[str] = None,
         priority: str = 'NORMAL',
         consumable_from: int = 0,
+        trace_id: typing.Optional[str] = None,
     ) -> bool:
+        trace_id = trace_id if trace_id is not None else self.get_trace_id()
         tasks = [
             objects.Task(
                 kwargs=kwargs,
+                trace_id=trace_id,
             )
             for kwargs in kwargs_list
         ]
@@ -213,9 +230,6 @@ class Worker:
         tasks_left = self.config.max_tasks_per_run
 
         while tasks_left > 0 or run_forever:
-            if self.stop_signal_received:
-                break
-
             if run_forever:
                 number_of_tasks_to_pull = self.config.tasks_per_transaction
             else:
@@ -242,8 +256,6 @@ class Worker:
                 try:
                     for task in tasks:
                         iterated_tasks += 1
-                        if self.stop_signal_received:
-                            break
 
                         yield task
                 finally:
@@ -307,9 +319,12 @@ class Worker:
         task_start_process_time = time.process_time()
 
         try:
-            self.executor_obj.execute_tasks(
-                tasks=self.iterate_tasks(),
-            )
+            if self.executor_obj:
+                self.executor_obj.execute_tasks(
+                    tasks=self.iterate_tasks(),
+                )
+            else:
+                raise RuntimeError('executor_obj is not set')
         except WorkerRespawn:
             summary['respawn'] = True
         except WorkerStop:
@@ -408,8 +423,8 @@ class Worker:
                 task=task,
                 returned_value=returned_value,
             )
-        except WorkerInterrupt as exception:
-            raise exception
+        except WorkerInterrupt:
+            raise
         except Exception as exception:
             self.logger.error(
                 msg=f'on_success handler has failed: {exception}',
@@ -448,8 +463,8 @@ class Worker:
             self.handle_requeue(
                 task=task,
             )
-        except WorkerInterrupt as exception:
-            raise exception
+        except WorkerInterrupt:
+            raise
         except Exception as exception:
             self.logger.error(
                 msg=f'on_failure handler has failed: {exception}',
@@ -486,8 +501,8 @@ class Worker:
             self.handle_requeue(
                 task=task,
             )
-        except WorkerInterrupt as exception:
-            raise exception
+        except WorkerInterrupt:
+            raise
         except Exception as exception:
             self.logger.error(
                 msg=f'on_timeout handler has failed: {exception}',
@@ -512,8 +527,8 @@ class Worker:
             self.on_retry(
                 task=task,
             )
-        except WorkerInterrupt as exception:
-            raise exception
+        except WorkerInterrupt:
+            raise
         except Exception as exception:
             self.logger.error(
                 msg=f'on_retry handler has failed: {exception}',
@@ -538,8 +553,8 @@ class Worker:
             self.on_max_retries(
                 task=task,
             )
-        except WorkerInterrupt as exception:
-            raise exception
+        except WorkerInterrupt:
+            raise
         except Exception as exception:
             self.logger.error(
                 msg=f'on_max_retries handler has failed: {exception}',
@@ -564,8 +579,8 @@ class Worker:
             self.on_requeue(
                 task=task,
             )
-        except WorkerInterrupt as exception:
-            raise exception
+        except WorkerInterrupt:
+            raise
         except Exception as exception:
             self.logger.error(
                 msg=f'on_requeue handler has failed: {exception}',
@@ -590,8 +605,8 @@ class Worker:
             self.on_starvation(
                 time_with_no_tasks=time_with_no_tasks,
             )
-        except WorkerInterrupt as exception:
-            raise exception
+        except WorkerInterrupt:
+            raise
         except Exception as exception:
             self.logger.error(
                 msg=f'on_starvation handler has failed: {exception}',
